==> moe-push-firebase-4.1.04-sources.jar: com/moengage/firebase/internal/repository/LocalRepositoryImpl.kt <==
/*
 * Copyright (c) 2014-2020 MoEngage Inc.
 *
 * All rights reserved.
 *
 *  Use of source code or binaries contained within MoEngage SDK is permitted only to enable use of the MoEngage platform by customers of MoEngage.
 *  Modification of source code and inclusion in mobile apps is explicitly allowed provided that all other conditions are met.
 *  Neither the name of MoEngage nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 *  Redistribution of source code or binaries is disallowed except with specific prior written permission. Any such redistribution must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.moengage.firebase.internal.repository

import android.content.Context
import com.moengage.core.ConfigurationProvider

/**
 * @author Arshiya Khanum
 * Date: 2020/07/20
 */
class LocalRepositoryImpl(private val context: Context) : LocalRepository {

    override fun savePushToken(token: String) {
        ConfigurationProvider.getInstance(context).fcmToken = token
    }

    override fun getPushToken(): String? {
        return ConfigurationProvider.getInstance(context).fcmToken
    }

    override fun isPushNotificationOptedOut(): Boolean {
        return ConfigurationProvider.getInstance(context)
            .isPushNotificationOptedOut
    }
}

==> moe-push-firebase-6.4.0-sources.jar: com/moengage/firebase/internal/repository/LocalRepositoryImpl.kt <==
/*
 * Copyright (c) 2014-2022 MoEngage Inc.
 *
 * All rights reserved.
 *
 *  Use of source code or binaries contained within MoEngage SDK is permitted only to enable use of the MoEngage platform by customers of MoEngage.
 *  Modification of source code and inclusion in mobile apps is explicitly allowed provided that all other conditions are met.
 *  Neither the name of MoEngage nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 *  Redistribution of source code or binaries is disallowed except with specific prior written permission. Any such redistribution must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.moengage.firebase.internal.repository

import android.content.Context
import com.moengage.core.internal.CoreInternalHelper
import com.moengage.core.internal.model.SdkInstance
import com.moengage.core.internal.model.SdkStatus
import com.moengage.core.internal.storage.preference.KEY_FCM_PUSH_TOKEN

/**
 * @author Arshiya Khanum
 * Date: 2020/07/20
 */
internal class LocalRepositoryImpl(
    private val context: Context,
    private val sdkInstance: SdkInstance
) : LocalRepository {

    override fun storePushToken(token: String) {
        CoreInternalHelper.storePushToken(context, sdkInstance, KEY_FCM_PUSH_TOKEN, token)
    }

    override fun getPushToken(): String {
        return CoreInternalHelper.getPushTokens(context, sdkInstance).fcmToken
    }

    override fun getSdkStatus(): SdkStatus {
        return CoreInternalHelper.getSdkStatus(context, sdkInstance)
    }

    override fun isStorageAndAPICallEnabled(): Boolean {
        return CoreInternalHelper.isStorageAndAPICallEnabled(context, sdkInstance)
    }
}
